package Catmandu::Fix::Date;
our $VERSION = "0.0121";

=head1 NAME

  Catmandu::Fix::Date - Catmandu fixes for processing dates

=head1 AUTHOR

Nicolas Franck, C<< <nicolas.franck at ugent.be> >>

=head1 SYNOPSIS

  For documentation on these fixes see:

    L<Catmandu::Fix::datetime_format>
    L<Catmandu::Fix::timestamp>

=head1 SEE ALSO

  L<Catmandu::Fix::datetime_format>
  L<Catmandu::Fix::timestamp>

=cut

1;
